@@ -20,6 +20,9 @@ public:
     void setChannelsFeedUrl(const QString &hello);
     QString getChannelsFeedUrl() const;
 
+    void setShowRecentlyPlayedSongs(bool b);
+    bool isShowRecentlyPlayedSongs() const;
+
 protected:
     void changeEvent(QEvent *e);
 
